#cd proj_dir
#python setup.py sdist
#pip install twine

# commands to upload to the pypi test repository
# twine upload --repository-url https://test.pypi.org/legacy/ dist/*
# pip install --index-url https://test.pypi.org/simple/ distributions

# command to upload to the pypi repository
# twine upload dist/*
# pip install distributions



from setuptools import setup

# read the contents of your README file
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'shuffle_dist_cards', 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(name='shuffle_dist_cards',
      version='0.1.1',
      description='Shuffle and distribute cards ',
      author='Ajinkya Joshi',
      author_email='ajinkya.dj92@gmail.com',
      packages=['shuffle_dist_cards'],
      long_description=long_description,
      long_description_content_type="text/markdown",
      zip_safe=False)


# importing modules
import itertools
import random


# class for shuffling and distributing cards
class ShuffleDistCards:
    def __init__(self, no_of_players):
        """ Initializing all require var
        Arg:
        no_of_players - Total number of player playing
        Returns:
        Dictionary of players as a key and his cards list as value
        """
        self.no_of_cards = 52
        self.no_of_players = no_of_players
        self.deck = []
        self.card_dist_dict = {}

    def create_n_shuffle_deck(self):
        # make a deck of cards
        self.deck = list(itertools.product(range(1, 14), ['Spade', 'Heart', 'Diamond', 'Club']))
        # shuffle the cards
        random.shuffle(self.deck)

    def dist_cards(self):
        # Distribute cards among all the players
        for num in range(0, self.no_of_players):
            key = 'player_' + str(num + 1)
            self.card_dist_dict[key] = [self.deck[i] for i in list(range(num, self.no_of_cards, self.no_of_players))]
        return self.card_dist_dict
